==> cspyexamclient-0.0.4.tar.gz: cspyexamclient-0.0.4/README.md <==
# Coderschool Exam Client

![Version](https://img.shields.io/badge/Latest%20Version-v0.0.3-%2300b4d8.svg?&style=for-the-badge&logo=git&logoColor=white)
![Python](https://img.shields.io/badge/Python-%230096c7.svg?&style=for-the-badge&logo=python&logoColor=white)
![Google Colab](https://img.shields.io/badge/Google%20Colab-4285F4?style=for-the-badge&logo=googledrive&logoColor=white)

Update (28 Sep 2024): Complete exam notebook for M3.1

## About the project
Coderschool Exam Client (cspyexamclient) is a reimplementation of the legacy system, `cspyclient`, with a focus on managing and processing learner submissions for Data Science exams. Beyond replicating key features from the original system, this version addresses long-standing bugs caused by outdated content and insufficient maintenance.

This new system allows the operations team to take ownership of the exam content, to quickly resolve any issues as they arise. Additionally, it lays the foundation for integrating the [**auto-grading**](https://github.com/nauqh/autograde) system in future iterations, enhancing the efficiency and accuracy of the grading process.

## Features

### Submit - Resubmit - Reset

<img width="500" src="assets/test_submission.gif">

### Exam Summary

<img width="500" src="assets/exam_summary.png">

## Exam notebook
| Module       | Description       | Link                                                                                  |
|--------------|-------------------|---------------------------------------------------------------------------------------|
| M1.1         | Basic SQL         | https://colab.research.google.com/drive/1E3sppN-vjschXS46WTeqZnQSmRBcuggN?usp=sharing |
| M1.2         | Advanced SQL      | https://colab.research.google.com/drive/1i-aGTjpXL-En8kVFB0Cl8elHn9Z866yv?usp=sharing |
| M2.1         | Python 101        | https://colab.research.google.com/drive/1zX-ZgjEot_uGHh8x2nCl7hGWUklLuYeL?usp=sharing |
| M3.1         | Pandas 101        | https://colab.research.google.com/drive/143rJnko61nMUGGwMccgxaBJRA-CmJEqT?usp=sharing |
| M4.1         | Data Visualization| Exam is coding and feedback thus no questions generation needed                       |

==> cspyexamclient-0.0.5.tar.gz: cspyexamclient-0.0.5/README.md <==
# Coderschool Exam Client

![Version](https://img.shields.io/badge/Latest%20Version-v0.0.3-%2300b4d8.svg?&style=for-the-badge&logo=git&logoColor=white)
![Python](https://img.shields.io/badge/Python-%230096c7.svg?&style=for-the-badge&logo=python&logoColor=white)
![Google Colab](https://img.shields.io/badge/Google%20Colab-4285F4?style=for-the-badge&logo=googledrive&logoColor=white)

Update (28 Sep 2024): Complete exam notebook for M3.1

## About the project
Coderschool Exam Client (cspyexamclient) is a reimplementation of the legacy system, `cspyclient`, with a focus on managing and processing learner submissions for Data Science exams. Beyond replicating key features from the original system, this version addresses long-standing bugs caused by outdated content and insufficient maintenance.

This new system allows the operations team to take ownership of the exam content, to quickly resolve any issues as they arise. Additionally, it lays the foundation for integrating the [**auto-grading**](https://github.com/nauqh/autograde) system in future iterations, enhancing the efficiency and accuracy of the grading process.

## Features

### Submit - Resubmit - Reset

<img width="500" src="https://github.com/nauqh/cspyexamclient/blob/master/assets/test_submission.gif">

### Exam Summary

<img width="500" src="https://github.com/nauqh/cspyexamclient/blob/master/assets/exam_summary.png">

## Exam notebook
| Module       | Description       | Link                                                                                  |
|--------------|-------------------|---------------------------------------------------------------------------------------|
| M1.1         | Basic SQL         | https://colab.research.google.com/drive/1E3sppN-vjschXS46WTeqZnQSmRBcuggN?usp=sharing |
| M1.2         | Advanced SQL      | https://colab.research.google.com/drive/1i-aGTjpXL-En8kVFB0Cl8elHn9Z866yv?usp=sharing |
| M2.1         | Python 101        | https://colab.research.google.com/drive/1zX-ZgjEot_uGHh8x2nCl7hGWUklLuYeL?usp=sharing |
| M3.1         | Pandas 101        | https://colab.research.google.com/drive/143rJnko61nMUGGwMccgxaBJRA-CmJEqT?usp=sharing |
| M4.1         | Data Visualization| Exam is coding and feedback thus no questions generation needed                       |
